==> pymodelextractor-0.1.1.tar.gz: pymodelextractor-0.1.1/pymodelextractor/tests/learners_tests/test_pdfa_lstarcol_learner.py <==
import unittest

from pythautomata.automata_definitions.weighted_tomitas_grammars import WeightedTomitasGrammars

from pymodelextractor.learners.observation_table_learners.pdfa_lstarcol_learner import PDFALStarColLearner
from pymodelextractor.teachers.pdfa_teacher import PDFATeacher


class TestPDFALStarColLearner(unittest.TestCase):

    def setUp(self):
        self.learner = PDFALStarColLearner()

    def test_tomitas_1(self):
        model = WeightedTomitasGrammars.get_automaton_1()
        teacher = PDFATeacher(model, 0)
        extracted_model = self.learner.learn(teacher)
        self.assertEqual(model, extracted_model)

    def test_tomitas_2(self):
        model = WeightedTomitasGrammars.get_automaton_2()
        teacher = PDFATeacher(model, 0)
        extracted_model = self.learner.learn(teacher)
        self.assertEqual(model, extracted_model)

    def test_tomitas_3(self):
        model = WeightedTomitasGrammars.get_automaton_3()
        teacher = PDFATeacher(model, 0)
        extracted_model = self.learner.learn(teacher)
        self.assertEqual(model, extracted_model)

    def test_tomitas_4(self):
        model = WeightedTomitasGrammars.get_automaton_4()
        teacher = PDFATeacher(model, 0)
        extracted_model = self.learner.learn(teacher)
        self.assertEqual(model, extracted_model)

    def test_tomitas_5(self):
        model = WeightedTomitasGrammars.get_automaton_5()
        teacher = PDFATeacher(model, 0)
        extracted_model = self.learner.learn(teacher)
        self.assertEqual(model, extracted_model)

    def test_tomitas_6(self):
        model = WeightedTomitasGrammars.get_automaton_6()
        teacher = PDFATeacher(model, 0)
        extracted_model = self.learner.learn(teacher)
        self.assertEqual(model, extracted_model)

    def test_tomitas_7(self):
        model = WeightedTomitasGrammars.get_automaton_7()
        teacher = PDFATeacher(model, 0)
        extracted_model = self.learner.learn(teacher)
        self.assertEqual(model, extracted_model)

==> pymodelextractor-0.2.0.tar.gz: pymodelextractor-0.2.0/pymodelextractor/tests/learners_tests/test_pdfa_lstarcol_learner.py <==
import unittest

from pythautomata.automata_definitions.weighted_tomitas_grammars import WeightedTomitasGrammars

from pymodelextractor.learners.observation_table_learners.pdfa_lstarcol_learner import PDFALStarColLearner
from pymodelextractor.teachers.pdfa_teacher import PDFATeacher


class TestPDFALStarColLearner(unittest.TestCase):

    def setUp(self):
        self.learner = PDFALStarColLearner()

    def test_tomitas_1(self):
        model = WeightedTomitasGrammars.get_automaton_1()
        teacher = PDFATeacher(model, 0)
        extracted_model = self.learner.learn(teacher).model
        self.assertEqual(model, extracted_model)

    def test_tomitas_2(self):
        model = WeightedTomitasGrammars.get_automaton_2()
        teacher = PDFATeacher(model, 0)
        extracted_model = self.learner.learn(teacher).model
        self.assertEqual(model, extracted_model)

    def test_tomitas_3(self):
        model = WeightedTomitasGrammars.get_automaton_3()
        teacher = PDFATeacher(model, 0)
        extracted_model = self.learner.learn(teacher).model
        self.assertEqual(model, extracted_model)

    def test_tomitas_4(self):
        model = WeightedTomitasGrammars.get_automaton_4()
        teacher = PDFATeacher(model, 0)
        extracted_model = self.learner.learn(teacher).model
        self.assertEqual(model, extracted_model)

    def test_tomitas_5(self):
        model = WeightedTomitasGrammars.get_automaton_5()
        teacher = PDFATeacher(model, 0)
        extracted_model = self.learner.learn(teacher).model
        self.assertEqual(model, extracted_model)

    def test_tomitas_6(self):
        model = WeightedTomitasGrammars.get_automaton_6()
        teacher = PDFATeacher(model, 0)
        extracted_model = self.learner.learn(teacher).model
        self.assertEqual(model, extracted_model)

    def test_tomitas_7(self):
        model = WeightedTomitasGrammars.get_automaton_7()
        teacher = PDFATeacher(model, 0)
        extracted_model = self.learner.learn(teacher).model
        self.assertEqual(model, extracted_model)
